@@ -128,7 +128,7 @@ void apwalapp_selected_app_modified(apwalapp_t *apwal)
     iconsel_refresh_selected(apwal->iconsel);
     break;
   default:
-    ERR("call by page:%d", page); //FIXME: ERR for debug only
+    ERR("BUG: should not happend, call from page:%d", page); 
   }
  /*
     // if icon selection window is showed and editor has focus
@@ -200,7 +200,7 @@ void apwalapp_selected_icon_modified(apwalapp_t *apwal)
 
   if (refresh_iconsel == TRUE)
   {
-    //FIXME: refresh already done by iconsel by it own
+    //refresh already done by iconsel, not needed:
     //iconsel_refresh(apwal->iconsel);
   }
   if (refresh_editor == TRUE)
@@ -747,8 +747,8 @@ static gboolean apwalapp_window_key_release_event(GtkWidget *widget,
 #if 0 /*do it if find a real interest in doing it*/
       case GDK_KP_Space:
       case GDK_space:
-      case GDK_Return:  //FIXME: not catcht because of key binding!
-      case GDK_KP_Enter: //FIXME: not catcht because of key binding!
+      case GDK_Return:  // NOT catcht because of key binding!
+      case GDK_KP_Enter: // NOT catcht because of key binding!
         if (apwal->selected_app != NULL)
           apwalapp_goto_iconsel(apwal);
         break;
