@@ -41,9 +41,6 @@
 #include <gtk/gtk.h>
 #include "cereimg.h"
 //#include "gtkintl.h"
-
-#include "fromgtk2src/gtkmarshalers.h"  // FIXME: 
-
 //#include "log.h"
 
 static void cereimg_get_property  (GObject                    *object,
@@ -245,7 +242,7 @@ cereimg_class_init (CereimgClass *class)
                  G_SIGNAL_RUN_LAST,
                  G_STRUCT_OFFSET (CereimgClass, clicked),
                  NULL, NULL,
-                 _gtk_marshal_VOID__STRING,
+                 g_cclosure_marshal_VOID__STRING,
                  G_TYPE_NONE, 1,
                  G_TYPE_STRING);
   
@@ -522,8 +519,8 @@ cereimg_render (GtkCellRenderer  *cell,
     gdk_gc_set_rgb_fg_color (gc, &cellimg->background_color);
     gdk_draw_rectangle (window, gc, TRUE,
                         background_area->x, background_area->y,
-                        background_area->width+2, background_area->height);
-    //FIXME: background_area->width+2 au lieu de background_area->width !!!!!
+                        background_area->width, background_area->height);
+    //background_area->width+2 not needed anymore.
   }
   else
   {
