@@ -1339,7 +1339,8 @@ static void iconsel_path_cereimg_clicked(Cereimg *cell, gchar *path_str,
 void iconsel_filesel_compute(const char *oldd, const char *newd, void *data)
 {
   icon_selection_t *iconsel = (icon_selection_t *)data;
-  char *olddir = (char*) oldd; //FIXME: do that in the proper way
+  //FIXME: modify icon_dir_list_modify & cie with const char* to avoid cast.
+  char *olddir = (char*) oldd;
   char *newdir = (char*) newd;
   icodir_t *icodir;
   g_assert(iconsel != NULL);
@@ -1357,7 +1358,6 @@ void iconsel_filesel_compute(const char *oldd, const char *newd, void *data)
   }
   else
   {
-    //FIXME:
     icodir = icon_list_find_path(iconsel->icons, newdir);
     if (icodir != NULL)
     {
