@@ -23,30 +23,61 @@
 #include <string.h>
 #include <stdio.h>
 
+void usage(char *exec)
+{
+    fprintf(stderr, "usage: %s [--edit] [--config <config file>]\n", exec);
+    exit(1);
+}
+
 int main(int argc, char **argv)
 {
   launcher_t *launcher;
   apwalapp_t *apwal;
+  gboolean    launch_editor = FALSE;
+  char       *config_file = NULL;
 
   gtk_init(&argc, &argv);
 
+  if (argc > 1)
+  {
+    int i;
+    for (i = 1; i < argc; i++)
+    {
+      TRACE();
+      if (strstr(argv[i], "--edit") != NULL)
+      {
+        launch_editor = TRUE;
+      }
+      else if (strstr(argv[i], "--config") != NULL)
+      {
+        i++;
+        if (i < argc)
+        {
+          config_file = argv[i];
+        }
+        else
+        {
+          usage(argv[0]);
+        }
+      }
+      else
+      {
+        usage(argv[0]);
+      }
+    }
+  }
+
+  xmlrc_set_resource_file(config_file); // NULL is ok.
+
   if (!xmlrc_resource_file_exist())
   {
     xmlrc_resource_file_create();
     apwal = apwalapp_new();
-  } else if (strstr(argv[0], "apwal-editor") != NULL)
+  }
+  else if (launch_editor)
   {
     apwal = apwalapp_new();
   }
-  else if ((argc >= 2) && (strstr(argv[1], "--edit") != NULL ))
-  {
-    apwal = apwalapp_new();
-  }
-  else if (argc >= 2)
-  {
-    fprintf(stderr, "usage: %s [--edit]\n", argv[0]);
-    exit(1);
-  }
   else
   {
     launcher = launcher_new();
