@@ -53,6 +53,11 @@
 //
 // ----------------------------------------------------------------------------
 
+// only access filerc by xmlrc_set_resource_file/xmlrc_resource_file
+static char g_xmlrc_filerc[FILENAME_MAX] = { 0 };
+
+static char*    xmlrc_resource_file(void);
+
 static app_list_t     * xmlrc_parse_apps(xmlDocPtr doc, xmlNodePtr cur);
 static app_t          * xmlrc_parse_app(xmlDocPtr doc, xmlNodePtr cur);
 
@@ -65,7 +70,6 @@ static icon_dir_t     * xmlrc_parse_icon_dir(xmlDocPtr doc, xmlNodePtr cur);
 static GList          * xmlrc_parse_file_exts(xmlDocPtr doc, xmlNodePtr cur);
 static file_ext_t     * xmlrc_parse_file_ext(xmlDocPtr doc, xmlNodePtr cur);
 
-static char*    xmlrc_resource_file(void);
 
 // ----------------------------------------------------------------------------
 // ----------------------------------------------------------------------------
@@ -132,13 +136,12 @@ void xmlrc_load_from_file(app_list_t **apps, iconsel_pref_t **iconsel_pref,
     cur = cur->next;
   } //end while cur
 
-  // To load version 0.3.31 and < resource file
-  // FIXME: remove it when cbwan has the new version
+  if (apps_is_loaded == FALSE)
+    ERR("apps section not found in rc file:%s", xmlrc_resource_file());
+  if (iconsel_pref_is_loaded == FALSE)
+    ERR("iconsel_pref section not found in rc file:%s", xmlrc_resource_file());
   if (apwal_pref_is_loaded == FALSE)
-    *apwal_pref = apwal_pref_new_default();
-
-  if (iconsel_pref_is_loaded == FALSE && iconsel_pref != NULL)
-    ERR("%s", "iconsel_pref not found in apwal resource file");
+    ERR("apwal_pref section not found in rc file:%s", xmlrc_resource_file());
 
   // free tree
   xmlFreeDoc(doc);
@@ -578,21 +581,30 @@ void xmlrc_save_to_file(app_list_t *apps, iconsel_pref_t *iconsel_pref,
 // ----------------------------------------------------------------------------
 // ----------------------------------------------------------------------------
 // ----------------------------------------------------------------------------
-// ----------------------------------------------------------------------------
-static char* xmlrc_resource_file(void)
+void xmlrc_set_resource_file(char *config_file)
 {
-  static char file[FILENAME_MAX] = { 0 };
-  if (file[0] == '\0')
+  g_assert(g_xmlrc_filerc[0] == '\0'); // set filerc ONE time only
+  if (config_file != NULL)
+  {
+    if (strlen(config_file) >= FILENAME_MAX)
+      ERR("config file name:%d to big", strlen(config_file));
+    strcat(g_xmlrc_filerc, config_file);
+  }
+  else
   {
     char *home;
     home = getenv("HOME");
     if (home == NULL)
       ERR("%s", "environement variable $HOME not set");
-    strcpy(file, home);
-    strcat(file, "/.apwalrc.xml");
+    strcpy(g_xmlrc_filerc, home);
+    strcat(g_xmlrc_filerc, "/.apwalrc.xml");
   }
-
-  return file;
+}
+// ----------------------------------------------------------------------------
+static char* xmlrc_resource_file(void)
+{
+  g_assert(g_xmlrc_filerc[0] != '\0'); // filerc have to be set
+  return g_xmlrc_filerc;
 }
 // ----------------------------------------------------------------------------
 gboolean xmlrc_resource_file_exist(void)
